gbranden pushed a commit to branch master
in repository groff.
commit 99b9d4acb1fdaa086f30f863923b3e7e82eac2a5
Author: G. Branden Robinson <[email protected]>
AuthorDate: Wed Jun 16 00:17:33 2021 +1000
src/roff/troff/input.cpp: Say "trap-called" macro.
* src/roff/troff/input.cpp (spring_trap): Tighten lexical discipline;
describe macro as "trap-called" rather than "trap-invoked".
---
ChangeLog | 6 ++++++
src/roff/troff/input.cpp | 4 ++--
2 files changed, 8 insertions(+), 2 deletions(-)
diff --git a/ChangeLog b/ChangeLog
index fd521cc..82f4ddc 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,9 @@
+2021-06-16 G. Branden Robinson <[email protected]>
+
+ * src/roff/troff/input.cpp (spring_trap): Tighten lexical
+ discipline; describe macro as "trap-called" rather than
+ "trap-invoked".
+
2021-06-15 G. Branden Robinson <[email protected]>
[man]: Don't spuriously break a page after a paragraph tag when
diff --git a/src/roff/troff/input.cpp b/src/roff/troff/input.cpp
index f861831..1cb8399 100644
--- a/src/roff/troff/input.cpp
+++ b/src/roff/troff/input.cpp
@@ -2596,7 +2596,7 @@ void exit_troff()
tok.next();
process_input_stack();
}
// This will only happen if a trap-invoked macro starts a diversion,
// or if vertical position traps have been disabled.
cleanup_and_exit(0);
}
@@ -4075,7 +4075,7 @@ void spring_trap(symbol nm)
request_or_macro *p = lookup_request(nm);
macro *m = p->to_macro();
if (m)
- input_stack::push(new macro_iterator(nm, *m, "trap-invoked macro"));
+ input_stack::push(new macro_iterator(nm, *m, "trap-called macro"));
else
error("you can't invoke a request with a trap");
input_stack::push(make_temp_iterator(buf));
@@ -2596,7 +2596,7 @@ void exit_troff()
process_input_stack();
}
- // This will only happen if a trap-invoked macro starts a diversion,
+ // This will only happen if a trap-called macro starts a diversion,
// or if vertical position traps have been disabled.
cleanup_and_exit(0);
_______________________________________________
Groff-commit mailing list
[email protected]
https://lists.gnu.org/mailman/listinfo/groff-commit